# -*- coding: utf-8 -*-

from rest_framework import serializers
from thx.api.serializers import (
    ThuxCreateSerializerMixin, ThuxDisableSerializerMixin, ThuxEnableSerializerMixin, ThuxListSerializerMixin,
    ThuxPartialUpdateSerializerMixin, ThuxRetrieveSerializerMixin, ThuxUpdateSerializerMixin,
)

from ... import models


# NOTIFICATION
class NotificationSerializer(serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_notify_notification'
        model = models.Notification
        fields = '__all__'


class NotificationListSerializer(ThuxListSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_notify_notification_list'
        model = models.Notification
        fields = '__all__'

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


class NotificationRetrieveSerializer(ThuxRetrieveSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_notify_notification_retrieve'
        model = models.Notification
        fields = '__all__'

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


class NotificationCreateSerializer(ThuxCreateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_notify_notification_create'
        model = models.Notification
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = NotificationRetrieveSerializer

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


class NotificationUpdateSerializer(ThuxUpdateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_notify_notification_update'
        model = models.Notification
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = NotificationRetrieveSerializer

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


class NotificationPartialUpdateSerializer(ThuxPartialUpdateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_notify_notification_partial_update'
        model = models.Notification
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = NotificationRetrieveSerializer

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


class NotificationEnableSerializer(ThuxEnableSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_notify_notification_enable'
        model = models.Notification
        fields = ()
        response_serializer = NotificationRetrieveSerializer

    def update(self, instance, validated_data):
        instance.status = 1
        instance.save()
        return instance


class NotificationDisableSerializer(ThuxDisableSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_notify_notification_disable'
        model = models.Notification
        fields = ()
        response_serializer = NotificationRetrieveSerializer

    def update(self, instance, validated_data):
        instance.status = 0
        instance.save()
        return instance


class NotificationLightSerializer(ThuxListSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_notify_notification_light'
        model = models.Notification
        fields = ('id', 'status', 'status_display',)

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


# NOTIFICATION RECIPIENT
class NotificationRecipientSerializer(serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_notify_notification_recipient'
        model = models.NotificationRecipient
        fields = '__all__'


class NotificationRecipientListSerializer(ThuxListSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_notify_notification_recipient_list'
        model = models.NotificationRecipient
        fields = '__all__'

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


class NotificationRecipientRetrieveSerializer(ThuxRetrieveSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_notify_notification_recipient_retrieve'
        model = models.NotificationRecipient
        fields = '__all__'

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


class NotificationRecipientCreateSerializer(ThuxCreateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_notify_notification_recipient_create'
        model = models.NotificationRecipient
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = NotificationRecipientRetrieveSerializer

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


class NotificationRecipientUpdateSerializer(ThuxUpdateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_notify_notification_recipient_update'
        model = models.NotificationRecipient
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = NotificationRecipientRetrieveSerializer

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


class NotificationRecipientPartialUpdateSerializer(ThuxPartialUpdateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_notify_notification_recipient_partial_update'
        model = models.NotificationRecipient
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = NotificationRecipientRetrieveSerializer

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


class NotificationRecipientEnableSerializer(ThuxEnableSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_notify_notification_recipient_enable'
        model = models.NotificationRecipient
        fields = ()
        response_serializer = NotificationRecipientRetrieveSerializer

    def update(self, instance, validated_data):
        instance.status = 1
        instance.save()
        return instance


class NotificationRecipientDisableSerializer(ThuxDisableSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_notify_notification_recipient_disable'
        model = models.NotificationRecipient
        fields = ()
        response_serializer = NotificationRecipientRetrieveSerializer

    def update(self, instance, validated_data):
        instance.status = 0
        instance.save()
        return instance


class NotificationRecipientLightSerializer(ThuxListSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_notify_notification_recipient_light'
        model = models.NotificationRecipient
        fields = ('id', 'status', 'status_display',)

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


# NOTIFICATION TYPE
class NotificationTypeSerializer(serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_notify_notification_type'
        model = models.NotificationType
        fields = '__all__'


class NotificationTypeListSerializer(ThuxListSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_notify_notification_type_list'
        model = models.NotificationType
        fields = '__all__'

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


class NotificationTypeRetrieveSerializer(ThuxRetrieveSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_notify_notification_type_retrieve'
        model = models.NotificationType
        fields = '__all__'

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


class NotificationTypeCreateSerializer(ThuxCreateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_notify_notification_type_create'
        model = models.NotificationType
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = NotificationTypeRetrieveSerializer

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


class NotificationTypeUpdateSerializer(ThuxUpdateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_notify_notification_type_update'
        model = models.NotificationType
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = NotificationTypeRetrieveSerializer

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


class NotificationTypePartialUpdateSerializer(ThuxPartialUpdateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_notify_notification_type_partial_update'
        model = models.NotificationType
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = NotificationTypeRetrieveSerializer

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


class NotificationTypeEnableSerializer(ThuxEnableSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_notify_notification_type_enable'
        model = models.NotificationType
        fields = ()
        response_serializer = NotificationTypeRetrieveSerializer

    def update(self, instance, validated_data):
        instance.status = 1
        instance.save()
        return instance


class NotificationTypeDisableSerializer(ThuxDisableSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_notify_notification_type_disable'
        model = models.NotificationType
        fields = ()
        response_serializer = NotificationTypeRetrieveSerializer

    def update(self, instance, validated_data):
        instance.status = 0
        instance.save()
        return instance


class NotificationTypeLightSerializer(ThuxListSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_notify_notification_type_light'
        model = models.NotificationType
        fields = ('id', 'status', 'status_display',)

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []
